@@ -19,7 +19,7 @@
 
 from minio import Minio
 
-client = Minio('play.min.io:9000',
+client = Minio('play.min.io',
                access_key='Q3AM3UQ867SPQQA43P2F',
                secret_key='zuf+tfteSlswRu7BJ86wekitnifILbZam1KYY3TG')
 
