@@ -28,8 +28,12 @@ from __future__ import absolute_import
 # if math.ceil returns an integer and devide two integers returns a float, calculate
 # part size will cause errors, so make sure division integers returns a float.
 from __future__ import division
-import io
 
+from __future__ import unicode_literals
+# future_str is unicode or str in both Python 2 and 3
+from builtins import str as future_str
+
+import io
 import collections
 import base64
 import hashlib
@@ -44,16 +48,27 @@ from .error import (InvalidBucketError, InvalidEndpointError,
                     InvalidArgumentError)
 
 # Constants
-MAX_MULTIPART_COUNT = 10000 # 10000 parts
+MAX_MULTIPART_COUNT = 10000  # 10000 parts
 MAX_MULTIPART_OBJECT_SIZE = 5 * 1024 * 1024 * 1024 * 1024  # 5TiB
 MAX_PART_SIZE = 5 * 1024 * 1024 * 1024  # 5GiB
 MAX_POOL_SIZE = 10
 MIN_PART_SIZE = 5 * 1024 * 1024  # 5MiB
-DEFAULT_PART_SIZE = MIN_PART_SIZE # Currently its 5MiB
+DEFAULT_PART_SIZE = MIN_PART_SIZE  # Currently its 5MiB
+
+
+# Select Object Content
+READ_SIZE_SELECT = 32 * 1024  # Buffer size
+SQL = 'SQL'  # Value for ExpressionType
+EVENT_RECORDS = 'Records'  # Event Type is Records
+EVENT_PROGRESS = 'Progress'  # Event Type Progress
+EVENT_STATS = 'Stats'  # Event Type Stats
+EVENT = 'event'  # Message Type is event
+EVENT_END = 'End'  # Event Type is End
+ERROR = 'error'  # Message Type is error
 
 _VALID_BUCKETNAME_REGEX = re.compile('^[a-z0-9][a-z0-9\\.\\-]+[a-z0-9]$')
 _ALLOWED_HOSTNAME_REGEX = re.compile(
-    '^((?!-)[A-Z\\d-]{1,63}(?<!-)\\.)*((?!-)[A-Z\\d-]{1,63}(?<!-))$',
+    '^((?!-)(?!_)[A-Z_\\d-]{1,63}(?<!-)(?<!_)\\.)*((?!_)(?!-)[A-Z_\\d-]{1,63}(?<!-)(?<!_))$',
     re.IGNORECASE)
 
 _EXTRACT_REGION_REGEX = re.compile('s3[.-]?(.+?).amazonaws.com')
@@ -654,6 +669,16 @@ def optimal_part_info(length, part_size):
 def amzprefix_user_metadata(metadata):
     m = dict()
     for k,v in metadata.items():
+       # Check if metadata value has US-ASCII encoding since it is
+       # the only one supported by HTTP headers. This will show a better
+       # exception message when users pass unsupported characters
+       # in metadata values.
+       try:
+            if isinstance(v, future_str):
+                 v.encode('us-ascii')
+       except UnicodeEncodeError:
+            raise ValueError('Metadata supports only US-ASCII characters.')
+
        if is_amz_header(k) or is_supported_header(k) or is_storageclass_header(k):
             m[k] = v
        else:
